@@ -109,9 +109,11 @@ class FormaDePagamentoConfiguracao(models.FormaPagamentoConfiguracao, Plugavel):
     def save(self, *args, **kwargs):
         self.desconto_tipo = self.TIPO_PORCENTAGEM
         self.desconto = self.desconto_valor and True or False
-        if self.maximo_parcelas != 0 and self.parcelas_sem_juros > self.maximo_parcelas:
-            self.parcelas_sem_juros = self.maximo_parcelas
-
+        if self.maximo_parcelas and self.parcelas_sem_juros:
+            self.parcelas_sem_juros = int(self.parcelas_sem_juros)
+            self.maximo_parcelas = int(self.maximo_parcelas)
+            if self.maximo_parcelas != 0 and self.parcelas_sem_juros > self.maximo_parcelas:
+                self.parcelas_sem_juros = self.maximo_parcelas
         if self.conta and not self.contrato_id:
             self.contrato_id = self.conta.contrato_id
 
@@ -188,7 +190,7 @@ class FormaDePagamentoConfiguracao(models.FormaPagamentoConfiguracao, Plugavel):
     @property
     def cadastro(self):
         try:
-            return self.plugin_configuracao.MeioPagamentoCadastro()
+            return self.plugin_configuracao.MeioPagamentoCadastro(self)
         except AttributeError:
             return None
             #FIXME: Pensar em um modelo melhor para determinar extensoes não obrigatórias
