@@ -4,7 +4,14 @@ import requests
 from pagador import settings
 
 
+def normaliza_conteudo_de_resposta(resposta):
+    if "content" in resposta:
+        if not type(resposta["content"]) is dict:
+            resposta["content"] = {"string": resposta["content"]}
+
+
 def grava_evidencia_envio(meio_pagamento, para, dados, resposta):
+    normaliza_conteudo_de_resposta(resposta)
     evidencia = {
         "tipo_evidencia": "pagador-envio",
         "evidencia": {
