@@ -19,8 +19,8 @@ class Enviar(object):
             @classmethod
             def formata_decimal(cls, valor, como_float=False):
                 if como_float:
-                    return float('{0:.3g}'.format(valor))
-                return '{0:.3g}'.format(valor)
+                    return float('{0:.2f}'.format(valor))
+                return '{0:.2f}'.format(valor)
 
             @classmethod
             def converte_tel_em_tupla_com_ddd(cls, telefone):
@@ -58,7 +58,7 @@ class EnviarPedido(Plugavel):
 
     def post(self, segunda_tentativa=False):
         conexao = Conexao(self.meio_pagamento, self.configuracao_pagamento, self.requisicao, TipoConexao.envio, self.processar_resposta)
-        return conexao.post(segunda_tentativa)
+        return conexao.get(segunda_tentativa)
 
     def enviar(self):
         resultado = self.post()
