@@ -97,7 +97,7 @@ class RegistrarPagamento(Plugavel):
             self.registrador.dados.update(self.obtem_dados_do_gateway())
         if self.registrador.alterar_situacao:
             if self.achou_registro:
-                resultado["pedido_venda_situacao"] = self.registrador.situacao_do_pedido
+                resultado["pedido_venda_situacao_id"] = self.registrador.situacao_do_pedido
                 notificador.envia_alteracao_de_situacao_de_pedido(self.registrador.pedido_numero, self.registrador.situacao_do_pedido, self.conta_id)
             else:
                 resultado = {"resultado": "erro", "mensagem": u"Nada foi registrado, pois os valores retornados não compõem um registro válido na LI."}
